pub fn render(frame: &mut Frame<'_>, state: &MapState, model: &GalaxyModel)Expand description
Bin systems into grid cells and render the full map frame.
pub fn render(frame: &mut Frame<'_>, state: &MapState, model: &GalaxyModel)Bin systems into grid cells and render the full map frame.